An retooling of github @david-wb's "23andme-to-vcf" command line code to work with inline python code.
    
Developed to enhance business capabilities for the government contractor Spinsys.

Usage:
<br/>
<code>
import vcf_from_23andme
</code>
<br/>
<code>
vcf_from_23andme.from_file("C:/input_name.23andme", "C:/desired_output_name.vcf", "C:/my_fasta_file.fa.fasta", "C:/my_human_genome_file.fa.fai")
</code>